@@ -62,7 +62,7 @@ public final class TokenizerText implements Tokenizer
     // The code assumes that errors throw exception and so stop parsing.
     private final ErrorHandler errorHandler;
 
-    public static TokenizeTextBuilder create() { return new TokenizeTextBuilder() ; }
+    public static TokenizeTextBuilder create() { return new TokenizeTextBuilder(); }
 
     public static Tokenizer fromString(String string) { return create().fromString(string).build(); }
 
@@ -408,6 +408,10 @@ public final class TokenizerText implements Tokenizer
             //case CH_UNDERSCORE: reader.readChar(); token.setType(TokenType.UNDERSCORE);/*token.setImage(CH_UNDERSCORE);*/ return token;
             case CH_LT:         reader.readChar(); token.setType(TokenType.LT);        /*token.setImage(CH_LT);*/ return token;
             case CH_STAR:       reader.readChar(); token.setType(TokenType.STAR);      /*token.setImage(CH_STAR);*/ return token;
+            case CH_EMARK:      reader.readChar(); token.setType(TokenType.EMARK);     /*token.setImage(CH_EMARK);*/ return token;
+
+            // VAR overrides
+            //case CH_QMARK:      reader.readChar(); token.setType(TokenType.QMARK);      /*token.setImage(CH_EMARK);*/ return token;
 
             // XXX Multi-character symbols
             // Two character tokens && || GE >= , LE <=
@@ -451,7 +455,7 @@ public final class TokenizerText implements Tokenizer
 
             // Already got a + or - ...
             // readNumberNoSign
-            // Because next, old code proceses signs.
+            // Because next, old code processes signs.
             reader.pushbackChar(ch);
             signCh = ch;
             // Drop to next "if"
@@ -523,7 +527,7 @@ public final class TokenizerText implements Tokenizer
                     // Probably a corrupt file so treat as fatal.
                     fatal("Bad character in IRI (bad character: '<'): <%s[<]...>", stringBuilder.toString()); return null;
                 case TAB:
-                    error("Bad character in IRI (Tab character): <%s[tab]...>", stringBuilder.toString()); return null;
+                    error("Bad character in IRI (tab character): <%s[tab]...>", stringBuilder.toString()); break;
                 case '{': case '}': case '"': case '|': case '^': case '`' :
                     if ( ! VeryVeryLaxIRI )
                         warning("Illegal character in IRI (codepoint 0x%02X, '%c'): <%s[%c]...>", ch, (char)ch, stringBuilder.toString(), (char)ch);
