@@ -301,6 +301,11 @@ public class AlgebraGenerator
             return compileElementOptional(eltOpt, current);
         }
 
+        if ( elt instanceof ElementLateral ) {
+            ElementLateral eltLateral = (ElementLateral)elt;
+            return compileElementLateral(eltLateral, current);
+        }
+
         if ( elt instanceof ElementMinus ) {
             ElementMinus elt2 = (ElementMinus)elt;
             Op op = compileElementMinus(current, elt2);
@@ -349,17 +354,16 @@ public class AlgebraGenerator
     }
 
     protected Op compileElementNotExists(Op current, ElementNotExists elt2) {
-        Op op = compile(elt2.getElement());    // "compile", not "compileElement" --
-                                               // do simpliifcation
-        Expr expr = new E_Exists(elt2, op);
-        expr = new E_LogicalNot(expr);
+        Element subElt = elt2.getElement();
+        Op op = compile(subElt);    // "compile", not "compileElement" -- do simplifcation
+        Expr expr = new E_NotExists(subElt, op);
         return OpFilter.filter(expr, current);
     }
 
     protected Op compileElementExists(Op current, ElementExists elt2) {
-        Op op = compile(elt2.getElement());    // "compile", not "compileElement" --
-                                               // do simpliifcation
-        Expr expr = new E_Exists(elt2, op);
+        Element subElt = elt2.getElement();
+        Op op = compile(subElt);    // "compile", not "compileElement" -- do simplification
+        Expr expr = new E_Exists(subElt, op);
         return OpFilter.filter(expr, current);
     }
 
@@ -398,6 +402,12 @@ public class AlgebraGenerator
         return current;
     }
 
+    protected Op compileElementLateral(ElementLateral eltLateral, Op current) {
+        Element subElt = eltLateral.getLateralElement();
+        Op op = compileElement(subElt);
+        return OpLateral.create(current, op);
+    }
+
     protected Op compileBasicPattern(BasicPattern pattern) {
         return new OpBGP(pattern);
     }
