@@ -20,7 +20,7 @@ package org.apache.jena.sparql.expr;
 
 import static javax.xml.datatype.DatatypeConstants.* ;
 import static org.apache.jena.datatypes.xsd.XSDDatatype.* ;
-import static org.apache.jena.sparql.expr.ValueSpaceClassification.* ;
+import static org.apache.jena.sparql.expr.ValueSpace.*;
 
 import java.math.BigDecimal ;
 import java.math.BigInteger ;
@@ -30,9 +30,7 @@ import javax.xml.datatype.DatatypeFactory ;
 import javax.xml.datatype.Duration ;
 import javax.xml.datatype.XMLGregorianCalendar ;
 
-import org.apache.jena.JenaRuntime;
 import org.apache.jena.atlas.lib.DateTimeUtils ;
-import org.apache.jena.atlas.lib.StrUtils ;
 import org.apache.jena.atlas.logging.Log ;
 import org.apache.jena.datatypes.DatatypeFormatException ;
 import org.apache.jena.datatypes.RDFDatatype ;
@@ -41,7 +39,6 @@ import org.apache.jena.datatypes.xsd.XSDDatatype;
 import org.apache.jena.ext.xerces.DatatypeFactoryInst;
 import org.apache.jena.graph.Node ;
 import org.apache.jena.graph.NodeFactory ;
-import org.apache.jena.graph.Triple;
 import org.apache.jena.graph.impl.LiteralLabel ;
 import org.apache.jena.sparql.ARQInternalErrorException ;
 import org.apache.jena.sparql.SystemARQ ;
@@ -432,395 +429,13 @@ public abstract class NodeValue extends ExprNode
         return node.isNodeTriple() ;
     }
 
-    // ----------------------------------------------------------------
-    // ---- sameValueAs
-
-    // Disjoint value spaces : dateTime and dates are not comparable
-    // Every langtag implies another value space as well.
-
-    /** Return true if the two NodeValues are known to be the same value
-     *  return false if known to be different values,
-     *  throw ExprEvalException otherwise
-     */
-    public static boolean sameAs(NodeValue nv1, NodeValue nv2)
-    {
-        if ( nv1 == null || nv2 == null )
-            throw new ARQInternalErrorException("Attempt to sameValueAs on a null") ;
-
-        ValueSpaceClassification compType = classifyValueOp(nv1, nv2) ;
-
-        // Special case - date/dateTime comparison is affected by timezones and may be
-        // indeterminate based on the value of the dateTime/date.
-
-        switch (compType)
-        {
-            case VSPACE_NUM:
-                return XSDFuncOp.compareNumeric(nv1, nv2) == Expr.CMP_EQUAL ;
-            case VSPACE_DATETIME:
-            case VSPACE_DATE:
-            case VSPACE_TIME:
-            case VSPACE_G_YEAR :
-            case VSPACE_G_YEARMONTH :
-            case VSPACE_G_MONTH :
-            case VSPACE_G_MONTHDAY :
-            case VSPACE_G_DAY :
-            {
-                int x = XSDFuncOp.compareDateTime(nv1, nv2) ;
-                if ( x == Expr.CMP_INDETERMINATE )
-                    throw new ExprNotComparableException("Indeterminate dateTime comparison") ;
-                return  x == Expr.CMP_EQUAL ;
-            }
-            case VSPACE_DURATION:
-            {
-                int x = XSDFuncOp.compareDuration(nv1, nv2) ;
-                if ( x == Expr.CMP_INDETERMINATE )
-                	throw new ExprNotComparableException("Indeterminate duration comparison") ;
-                return  x == Expr.CMP_EQUAL ;
-            }
-
-            case VSPACE_STRING:     return XSDFuncOp.compareString(nv1, nv2) == Expr.CMP_EQUAL ;
-            case VSPACE_BOOLEAN:    return XSDFuncOp.compareBoolean(nv1, nv2) == Expr.CMP_EQUAL ;
-
-            case VSPACE_TRIPLE_TERM: {
-                Triple t1 = nv1.getNode().getTriple();
-                Triple t2 = nv2.getNode().getTriple();
-                return nSameAs(t1.getSubject(), t2.getSubject())
-                    && nSameAs(t1.getPredicate(), t2.getPredicate())
-                    && nSameAs(t1.getObject(), t2.getObject());
-            }
-
-            case VSPACE_LANG:
-            case VSPACE_NODE:
-                // Two non-literals
-                return NodeFunctions.sameTerm(nv1.getNode(), nv2.getNode()) ;
-
-            case VSPACE_UNKNOWN:
-            {
-                // One or two unknown value spaces, or one has a lang tag (but not both).
-                Node node1 = nv1.asNode() ;
-                Node node2 = nv2.asNode() ;
-
-                if ( ! SystemARQ.ValueExtensions )
-                    // No value extensions => raw rdfTermEquals
-                    return NodeFunctions.rdfTermEquals(node1, node2) ;
-
-                // Some "value spaces" are know to be not equal (no overlap).
-                // Like one literal with a language tag, and one without can't be sameAs.
-
-                if ( ! node1.isLiteral() || ! node2.isLiteral() )
-                    // Can't both be non-literals - that's VSPACE_NODE
-                    // One or other not a literal => not sameAs
-                    return false ;
-
-                // Two literals at this point.
-
-                if ( NodeFunctions.sameTerm(node1, node2) )
-                    return true ;
-
-                if ( ! node1.getLiteralLanguage().equals("") ||
-                     ! node2.getLiteralLanguage().equals("") )
-                    // One had lang tag but weren't sameNode => not equals
-                    return false ;
-
-                raise(new ExprEvalException("Unknown equality test: "+nv1+" and "+nv2)) ;
-                throw new ARQInternalErrorException("raise returned (sameValueAs)") ;
-            }
-            case VSPACE_SORTKEY:
-                return nv1.getSortKey().compareTo(nv2.getSortKey()) == 0 ;
-
-            case VSPACE_DIFFERENT:
-                // Known to be incompatible.
-                if ( ! SystemARQ.ValueExtensions && ( nv1.isLiteral() && nv2.isLiteral() ) )
-                    raise(new ExprEvalException("Incompatible: "+nv1+" and "+nv2)) ;
-                return false ;
-        }
-
-        throw new ARQInternalErrorException("sameValueAs failure "+nv1+" and "+nv2) ;
+    public ValueSpace getValueSpace() {
+        return classifyValueSpace(this);
     }
 
-    /** Worker for sameAs. */
-    private static boolean nSameAs(Node n1, Node n2) {
-        NodeValue nv1 = NodeValue.makeNode(n1);
-        NodeValue nv2 = NodeValue.makeNode(n2);
-        return sameAs(nv1, nv2);
-    }
-
-    /** Return true if the two Nodes are known to be different,
-     *  return false if the two Nodes are known to be the same,
-     *  else throw ExprEvalException
-     */
-    public static boolean notSameAs(Node n1, Node n2)
-    {
-        return notSameAs(NodeValue.makeNode(n1), NodeValue.makeNode(n2)) ;
-    }
-
-    /** Return true if the two NodeValues are known to be different,
-     *  return false if the two NodeValues are known to be the same,
-     *  else throw ExprEvalException
-     */
-    public static boolean notSameAs(NodeValue nv1, NodeValue nv2)
-    {
-        return ! sameAs(nv1, nv2) ;
-    }
-
-    // ----------------------------------------------------------------
-    // compare
-
-    // Compare by value code is here
-    // NodeUtils.compareRDFTerms for syntactic comparison
-
-    /** Compare by value if possible else compare by kind/type/lexical form
-     *  Only use when you want an ordering regardless of form of NodeValue,
-     *  for example in ORDER BY
-     *
-     * @param nv1
-     * @param nv2
-     * @return negative, 0, or positive for less than, equal, greater than.
-     */
-
-    public static int compareAlways(NodeValue nv1, NodeValue nv2)
-    {
-        try {
-            int x = compare(nv1, nv2, true) ;
-            // Same?
-            if ( x != Expr.CMP_EQUAL )
-                return x ;
-        } catch (ExprNotComparableException ex)
-        { /* Drop through */ }
-        return NodeUtils.compareRDFTerms(nv1.asNode(), nv2.asNode()) ;
-    }
-
-    /** Compare by value (and only value) if possible.
-     *  Supports &lt;, &lt;=, &gt;, &gt;= but not = nor != (which are sameValueAs and notSameValueAs)
-     * @param nv1
-     * @param nv2
-     * @return Expr.CMP_INDETERMINATE(+2), Expr.CMP_LESS(-1), Expr.CMP_EQUAL(0) or Expr.CMP_GREATER(+1)
-     * @throws ExprNotComparableException
-     */
-    public static int compare(NodeValue nv1, NodeValue nv2)
-    {
-        if ( nv1 == null || nv2 == null )
-            //raise(new ExprEvalException("Attempt to notSameValueAs on null") ;
-            throw new ARQInternalErrorException("Attempt to compare on null") ;
-        int x = compare(nv1, nv2, false) ;
-        return x ;
-    }
-
-    // E_GreaterThan/E_LessThan/E_GreaterThanOrEqual/E_LessThanOrEqual
-    // ==> compare(nv1, nv2) => compare (nv1, nv2, false)
-
-    // BindingComparator => compareAlways(nv1, nv2) => compare (nv1, nv2, true)
-
-    // E_Equals calls NodeValue.sameAs() ==>
-
-    // sortOrderingCompare means that the comparison should do something with normally unlike things,
-    // and split plain strings from xsd:strings.
-
-    private static int compare(NodeValue nv1, NodeValue nv2, boolean sortOrderingCompare)
-    {
-        if ( nv1 == null && nv2 == null )
-            return Expr.CMP_EQUAL ;
-
-        if ( nv1 == null )
-            return Expr.CMP_LESS ;
-        if ( nv2 == null )
-            return Expr.CMP_GREATER ;
-
-        ValueSpaceClassification compType = classifyValueOp(nv1, nv2) ;
-
-        // Special case - date/dateTime comparison is affected by timezones and may be
-        // indeterminate based on the value of the dateTime/date.
-        // Do this first,
-
-        switch (compType)
-        {
-            case VSPACE_DATETIME:
-            case VSPACE_DATE:
-            case VSPACE_TIME:
-            case VSPACE_G_DAY :
-            case VSPACE_G_MONTH :
-            case VSPACE_G_MONTHDAY :
-            case VSPACE_G_YEAR :
-            case VSPACE_G_YEARMONTH :
-            {
-                int x = XSDFuncOp.compareDateTime(nv1, nv2) ;
-                if ( x != Expr.CMP_INDETERMINATE )
-                    return x ;
-                // Indeterminate => can't compare as strict values.
-                compType = ValueSpaceClassification.VSPACE_DIFFERENT ;
-                break ;
-            }
-            case VSPACE_DURATION:
-            {
-                int x = XSDFuncOp.compareDuration(nv1, nv2) ;
-                // Fix up - Java (Oracle java7 at least) returns "equals" for
-                // "P1Y"/"P365D" and "P1M"/"P28D", and others split over
-                // YearMonth/DayTime.
-
-                // OR return Expr.CMP_INDETERMINATE ??
-                if ( x == Expr.CMP_EQUAL ) {
-                    Duration d1 = nv1.getDuration() ;
-                    Duration d2 = nv2.getDuration() ;
-                    if ( ( XSDFuncOp.isDayTime(d1) && XSDFuncOp.isYearMonth(d2) ) ||
-                         ( XSDFuncOp.isDayTime(d2) && XSDFuncOp.isYearMonth(d1) ) )
-                        x = Expr.CMP_INDETERMINATE ;
-                }
-                if ( x != Expr.CMP_INDETERMINATE )
-                    return x ;
-                compType = ValueSpaceClassification.VSPACE_DIFFERENT ;
-                break ;
-            }
-
-            // No special cases.
-            case VSPACE_BOOLEAN :
-            case VSPACE_DIFFERENT :
-            case VSPACE_LANG :
-            case VSPACE_TRIPLE_TERM:
-            case VSPACE_NODE :
-            case VSPACE_NUM :
-            case VSPACE_STRING :
-            case VSPACE_SORTKEY :
-            case VSPACE_UNKNOWN :
-                // Drop through.
-        }
-
-        switch (compType)
-        {
-            case VSPACE_DATETIME:
-            case VSPACE_DATE:
-            case VSPACE_TIME:
-            case VSPACE_G_DAY :
-            case VSPACE_G_MONTH :
-            case VSPACE_G_MONTHDAY :
-            case VSPACE_G_YEAR :
-            case VSPACE_G_YEARMONTH :
-            case VSPACE_DURATION:
-                throw new ARQInternalErrorException("Still seeing date/dateTime/time/duration compare type") ;
-
-            case VSPACE_NUM:        return XSDFuncOp.compareNumeric(nv1, nv2) ;
-            case VSPACE_STRING:
-            {
-                int cmp = XSDFuncOp.compareString(nv1, nv2) ;
-
-                if ( ! sortOrderingCompare )
-                    return cmp ;
-                if ( cmp != Expr.CMP_EQUAL )
-                    return cmp ;
-
-                // Equality.
-                if ( JenaRuntime.isRDF11 )
-                    // RDF 1.1 : No literals without datatype.
-                    return cmp ;
-
-                // RDF 1.0
-                // Split plain literals and xsd:strings for sorting purposes.
-                // Same by string value.
-                String dt1 = nv1.asNode().getLiteralDatatypeURI() ;
-                String dt2 = nv2.asNode().getLiteralDatatypeURI() ;
-                if ( dt1 == null && dt2 != null )
-                    return Expr.CMP_LESS ;
-                if ( dt2 == null && dt1 != null )
-                    return Expr.CMP_GREATER ;
-                return Expr.CMP_EQUAL;  // Both plain or both xsd:string.
-            }
-            case VSPACE_SORTKEY :
-                return nv1.getSortKey().compareTo(nv2.getSortKey());
-
-            case VSPACE_BOOLEAN:
-                return XSDFuncOp.compareBoolean(nv1, nv2) ;
-
-            case VSPACE_LANG:
-            {
-                // Two literals, both with language tags.
-                Node node1 = nv1.asNode() ;
-                Node node2 = nv2.asNode() ;
-                int x = StrUtils.strCompareIgnoreCase(node1.getLiteralLanguage(), node2.getLiteralLanguage()) ;
-
-                if ( x != Expr.CMP_EQUAL )
-                {
-                    // Different lang tags
-                    if ( ! sortOrderingCompare )
-                        raise(new ExprNotComparableException("Can't compare (different languages) "+nv1+" and "+nv2)) ;
-                    // Different lang tags - sorting
-                    return x ;
-                }
-
-                // same lang tag (case insensitive)
-                x = StrUtils.strCompare(node1.getLiteralLexicalForm(), node2.getLiteralLexicalForm()) ;
-                if ( x != Expr.CMP_EQUAL )
-                    return x ;
-                // Same lexical forms, same lang tag by value
-                // Try to split by syntactic lang tags.
-                x = StrUtils.strCompare(node1.getLiteralLanguage(), node2.getLiteralLanguage()) ;
-                // Maybe they are the same after all!
-                // Should be node.equals by now.
-                if ( x == Expr.CMP_EQUAL  && ! NodeFunctions.sameTerm(node1, node2) )
-                    throw new ARQInternalErrorException("Looks like the same (lang tags) but not node equals") ;
-                return x ;
-            }
-
-            case VSPACE_TRIPLE_TERM: {
-                Triple t1 = nv1.getNode().getTriple();
-                Triple t2 = nv2.getNode().getTriple();
-                int x = nCompare(t1.getSubject(), t2.getSubject(), sortOrderingCompare);
-                if ( x != CMP_EQUAL )
-                    return x;
-                x = nCompare(t1.getPredicate(), t2.getPredicate(), sortOrderingCompare);
-                if ( x != CMP_EQUAL )
-                    return x;
-                return nCompare(t1.getObject(), t2.getObject(), sortOrderingCompare);
-            }
-
-            case VSPACE_NODE:
-                // Two non-literals don't compare except for sorting.
-                if ( sortOrderingCompare )
-                    return NodeUtils.compareRDFTerms(nv1.asNode(), nv2.asNode()) ;
-                else
-                {
-                    raise(new ExprNotComparableException("Can't compare (nodes) "+nv1+" and "+nv2)) ;
-                    throw new ARQInternalErrorException("NodeValue.raise returned") ;
-                }
-
-            case VSPACE_UNKNOWN:
-            {
-                // One or two unknown value spaces.
-                Node node1 = nv1.asNode() ;
-                Node node2 = nv2.asNode() ;
-                // Two unknown literals can be equal.
-                if ( NodeFunctions.sameTerm(node1, node2) )
-                    return Expr.CMP_EQUAL ;
-
-                if ( sortOrderingCompare )
-                    return NodeUtils.compareRDFTerms(node1, node2) ;
-
-                raise(new ExprNotComparableException("Can't compare "+nv1+" and "+nv2)) ;
-                throw new ARQInternalErrorException("NodeValue.raise returned") ;
-            }
-
-            case VSPACE_DIFFERENT:
-                // Two literals, from different known value spaces
-                if ( sortOrderingCompare )
-                    return NodeUtils.compareRDFTerms(nv1.asNode(), nv2.asNode()) ;
-
-                raise(new ExprNotComparableException("Can't compare (incompatible value spaces)"+nv1+" and "+nv2)) ;
-                throw new ARQInternalErrorException("NodeValue.raise returned") ;
-        }
-        throw new ARQInternalErrorException("Compare failure "+nv1+" and "+nv2) ;
-    }
-
-    /** Worker for compare. */
-    private static int nCompare(Node n1, Node n2, boolean sortOrderingCompare) {
-        if ( n1.equals(n2) )
-            return CMP_EQUAL;
-        NodeValue nv1 = NodeValue.makeNode(n1);
-        NodeValue nv2 = NodeValue.makeNode(n2);
-        return compare(nv1, nv2, sortOrderingCompare);
-    }
-
-    public static ValueSpaceClassification classifyValueOp(NodeValue nv1, NodeValue nv2)
-    {
-        ValueSpaceClassification c1 = nv1.getValueSpace() ;
-        ValueSpaceClassification c2 = nv2.getValueSpace() ;
+    public static ValueSpace classifyValueOp(NodeValue nv1, NodeValue nv2) {
+        ValueSpace c1 = classifyValueSpace(nv1);
+        ValueSpace c2 = classifyValueSpace(nv2);
         if ( c1 == c2 ) return c1 ;
         if ( c1 == VSPACE_UNKNOWN || c2 == VSPACE_UNKNOWN )
             return VSPACE_UNKNOWN ;
@@ -829,36 +444,87 @@ public abstract class NodeValue extends ExprNode
         return VSPACE_DIFFERENT ;
     }
 
-    public ValueSpaceClassification getValueSpace()     { return classifyValueSpace(this) ; }
+    /*package*/ static ValueSpace classifyValueSpace(NodeValue nv) {
+        return ValueSpace.valueSpace(nv);
+    }
 
-    private static ValueSpaceClassification classifyValueSpace(NodeValue nv)
-    {
-        if ( nv.isNumber() )        return VSPACE_NUM ;
-        if ( nv.isDateTime() )      return VSPACE_DATETIME ;
-        if ( nv.isString())         return VSPACE_STRING ;
-        if ( nv.isBoolean())        return VSPACE_BOOLEAN ;
-        if ( nv.isTripleTerm())     return VSPACE_TRIPLE_TERM ;
-        if ( ! nv.isLiteral() )     return VSPACE_NODE ;
+    // ----------------------------------------------------------------
+    // ---- sameValueAs
 
-        if ( ! SystemARQ.ValueExtensions )
-            return VSPACE_UNKNOWN ;
+    // Disjoint value spaces : dateTime and dates are not comparable
+    // Every langtag implies another value space as well.
 
-        // Datatypes and their value spaces that are an extension of minimal SPARQL 1.1
-        if ( nv.isDate() )          return VSPACE_DATE ;
-        if ( nv.isTime() )          return VSPACE_TIME ;
-        if ( nv.isDuration() )      return VSPACE_DURATION ;
+    /**
+     * Return true if the two NodeValues are known to be the same value return false
+     * if known to be different values, throw ExprEvalException otherwise
+     */
+    public static boolean sameValueAs(NodeValue nv1, NodeValue nv2) {
+        return NodeValueCmp.sameValueAs(nv1, nv2);
+    }
 
-        if ( nv.isGYear() )         return VSPACE_G_YEAR ;
-        if ( nv.isGYearMonth() )    return VSPACE_G_YEARMONTH ;
-        if ( nv.isGMonth() )        return VSPACE_G_MONTH ;
-        if ( nv.isGMonthDay() )     return VSPACE_G_MONTHDAY ;
-        if ( nv.isGDay() )          return VSPACE_G_DAY ;
+    /** @deprecated Use {@link #sameValueAs(NodeValue, NodeValue)}. */
+    @Deprecated
+    public static boolean sameAs(NodeValue nv1, NodeValue nv2) {
+        return sameValueAs(nv1, nv2);
+    }
 
-        if ( nv.isSortKey() )       return VSPACE_SORTKEY ;
+    /**
+     * Return true if the two Nodes are known to be different, return false if the
+     * two Nodes are known to be the same, else throw ExprEvalException
+     */
+    public static boolean notSameValueAs(Node n1, Node n2) {
+        return notSameValueAs(NodeValue.makeNode(n1), NodeValue.makeNode(n2));
+    }
 
-        if ( NodeUtils.hasLang(nv.asNode()) )
-            return VSPACE_LANG ;
-        return VSPACE_UNKNOWN ;
+    /** @deprecated Use {@link #sameValueAs(NodeValue, NodeValue)}. */
+    @Deprecated
+    public static boolean notSameAs(Node n1, Node n2) {
+        return notSameValueAs(n1, n2);
+    }
+
+    /**
+     * Return true if the two NodeValues are known to be different, return false if
+     * the two NodeValues are known to be the same, else throw ExprEvalException
+     */
+    public static boolean notSameValueAs(NodeValue nv1, NodeValue nv2) {
+        return NodeValueCmp.notSameValueAs(nv1, nv2);
+    }
+
+    /** @deprecated Use {@link #sameValueAs(NodeValue, NodeValue)}. */
+    @Deprecated
+    public static boolean notSameAs(NodeValue nv1, NodeValue nv2) {
+        return notSameValueAs(nv1, nv2);
+    }
+
+    // ----------------------------------------------------------------
+    // compare
+
+    /** Compare by value (and only value) if possible.
+     *  Supports &lt;, &lt;=, &gt;, &gt;= but not = nor != (which are sameValueAs and notSameValueAs)
+     * @param nv1
+     * @param nv2
+     * @return Expr.CMP_LESS(-1), Expr.CMP_EQUAL(0) or Expr.CMP_GREATER(+1)
+     * @throws ExprNotComparableException for Expr.CMP_INDETERMINATE(+2)
+     */
+    public static int compare(NodeValue nv1, NodeValue nv2) {
+        //return NodeValueCompare.compare(nv1, nv2);
+        int x = NodeValueCmp.compareByValue(nv1, nv2);
+        if ( x == Expr.CMP_INDETERMINATE || x == Expr.CMP_UNEQUAL )
+            throw new ExprNotComparableException(null);
+        return x;
+    }
+    /**
+     * Compare by value if possible else compare by kind/type/lexical form
+     * Only use when you want an ordering regardless of form of NodeValue,
+     * for example in ORDER BY
+     *
+     * @param nv1
+     * @param nv2
+     * @return negative, 0, or positive for less than, equal, greater than.
+     */
+    public static int compareAlways(NodeValue nv1, NodeValue nv2) {
+        //return NodeValueCompare.compareAlways(nv1, nv2);
+        return NodeValueCmp.compareAlways(nv1, nv2);
     }
 
     // ----------------------------------------------------------------
@@ -1005,7 +671,6 @@ public abstract class NodeValue extends ExprNode
         if ( NodeUtils.hasLang(node) )
             return new NodeValueLang(node) ;
         LiteralLabel lit = node.getLiteral() ;
-        String lex = lit.getLexicalForm() ;
         RDFDatatype datatype = lit.getDatatype() ;
 
         // Quick check.
@@ -1017,10 +682,12 @@ public abstract class NodeValue extends ExprNode
             return null ;
         }
 
+        String lex = lit.getLexicalForm() ;
+
         try { // DatatypeFormatException - should not happen
             if ( XSDstring.isValidLiteral(lit) )
                 // String - plain or xsd:string, or derived datatype.
-                return new NodeValueString(lit.getLexicalForm(), node) ;
+                return new NodeValueString(lex, node) ;
 
             // Otherwise xsd:string is like any other unknown datatype.
             // Ditto literals with language tags (which are handled by nodeToNodeValue)
@@ -1151,9 +818,8 @@ public abstract class NodeValue extends ExprNode
     // ----------------------------------------------------------------
 
     // Point to catch all exceptions.
-    public static void raise(ExprException ex)
-    {
-        throw ex ;
+    public static void raise(ExprException ex) {
+        throw ex;
     }
 
     @Override
@@ -1178,28 +844,25 @@ public abstract class NodeValue extends ExprNode
     public final String asQuotedString()
     { return asQuotedString(new SerializationContext()) ; }
 
-    public final String asQuotedString(SerializationContext context)
-    {
+    public final String asQuotedString(SerializationContext context) {
         // If possible, make a node and use that as the formatted output.
         if ( node == null )
-            node = asNode() ;
+            node = asNode();
         if ( node != null )
-            return FmtUtils.stringForNode(node, context) ;
-        return toString() ;
+            return FmtUtils.stringForNode(node, context);
+        return toString();
     }
 
-    // Convert to a string  - usually overridden.
-    public String asString()
-    {
+    // Convert to a string - usually overridden.
+    public String asString() {
         // Do not call .toString()
-        forceToNode() ;
-        return NodeFunctions.str(node) ;
+        forceToNode();
+        return NodeFunctions.str(node);
     }
 
     @Override
-    public int hashCode()
-    {
-        return asNode().hashCode() ;
+    public int hashCode() {
+        return asNode().hashCode();
     }
 
     @Override
@@ -1207,7 +870,6 @@ public abstract class NodeValue extends ExprNode
         if ( other == null ) return false ;
         if ( this == other ) return true ;
         // This is the equality condition Jena uses - lang tags are different by case.
-
         if ( ! ( other instanceof NodeValue ) )
             return false ;
         NodeValue nv = (NodeValue)other ;
