@@ -82,6 +82,7 @@ public class BuilderOp
         addBuild(Tags.tagMinus,         buildMinus);
         addBuild(Tags.tagUnion,         buildUnion);
         addBuild(Tags.tagDatasetNames,  buildDatasetNames);
+        addBuild(Tags.tagLateral,       buildLateral);
         addBuild(Tags.tagConditional,   buildConditional);
 
         addBuild(Tags.tagToList,        buildToList);
@@ -358,6 +359,14 @@ public class BuilderOp
 		return new OpDatasetNames(n);
     };
 
+    final protected Build buildLateral = (ItemList list) -> {
+        BuilderLib.checkLength(3, 4, list, "lateral");
+        Op left = build(list, 1);
+        Op right = build(list, 2);
+        Op op = OpLateral.create(left, right);
+        return op;
+    };
+
     final protected Build buildConditional = (ItemList list) -> {
 		BuilderLib.checkLength(2, 3, list, "condition");
 		Op left = build(list, 1);
