@@ -26,10 +26,9 @@ import org.junit.runner.RunWith ;
 /** The test suites - these are driven by a manifest file and use external files for tests */
 
 @RunWith(RunnerRIOT.class)
-@Label("RIOT")
+@Label("RIOT Scripts")
 @Manifests({
     "testing/RIOT/Lang/manifest-all.ttl"
-    // RDF-star tests also in Scripts_ARQ which runs the entire suite of community tests.
 })
 
 public class Scripts_LangSuite
