@@ -32,6 +32,7 @@ import org.apache.jena.rdf.model.Model;
 import org.apache.jena.rdf.model.ModelFactory;
 import org.apache.jena.sparql.expr.nodevalue.XSDFuncOp ;
 import org.apache.jena.sparql.sse.SSE;
+import org.apache.jena.sparql.util.NodeCmp;
 import org.apache.jena.sparql.util.NodeFactoryExtra ;
 import org.junit.AfterClass ;
 import org.junit.BeforeClass ;
@@ -237,11 +238,16 @@ public class TestNodeValue
         assertEquals("Not Calendar.equals: ", v0.getDateTime(), v1.getDateTime());
     }
 
+    private static NodeValue parse(String nodeString) {
+        Node n = SSE.parseNode(nodeString);
+        NodeValue nv = NodeValue.makeNode(n);
+        return nv;
+    }
+
     @Test
     public void testDateTimeStamp1() {
         // xsd:dateTimeStamp is a derived datatype of xsd:dateTime.
-        Node n = SSE.parseNode("'2000-01-01T00:00:00+00:00'^^xsd:dateTimeStamp");
-        NodeValue nv = NodeValue.makeNode(n);
+        NodeValue nv = parse("'2000-01-01T00:00:00+00:00'^^xsd:dateTimeStamp");
         assertTrue(nv.isDateTime());
         assertFalse(nv.isDate());
     }
@@ -810,14 +816,14 @@ public class TestNodeValue
     public void testFloatDouble1() {
         NodeValue v1 = NodeValue.makeNodeDouble("1.5");
         NodeValue v2 = NodeValue.makeNode("1.5", XSDDatatype.XSDfloat);
-        assertTrue("Should be equal: 1.5 float and 1.5 double", NodeValue.sameAs(v1, v2));
+        assertTrue("Should be equal: 1.5 float and 1.5 double", NodeValue.sameValueAs(v1, v2));
     }
 
     @Test
     public void testFloatDouble5() {
         NodeValue v1 = NodeValue.makeNodeDouble("1.3");
         NodeValue v2 = NodeValue.makeNode("1.3", XSDDatatype.XSDfloat);
-        assertFalse("Should not be equal: 1.3 float and 1.3 double", NodeValue.sameAs(v1, v2));
+        assertFalse("Should not be equal: 1.3 float and 1.3 double", NodeValue.sameValueAs(v1, v2));
     }
 
     // More effective boolean values - see TestExpressionARQ
@@ -892,7 +898,7 @@ public class TestNodeValue
         });
         List<String> result = new LinkedList<>();
         for (NodeValue nv : nodeValues) {
-            String s = nv.getNode().getLiteralLexicalForm();
+            String s = nv.asNode().getLiteralLexicalForm();
             result.add(s);
         }
         assertArrayEquals(ordered, result.toArray(new String[0]));
@@ -918,7 +924,7 @@ public class TestNodeValue
         });
         List<String> result = new LinkedList<>();
         for (NodeValue nv : nodeValues) {
-            String s = nv.getNode().getLiteralLexicalForm();
+            String s = nv.asNode().getLiteralLexicalForm();
             result.add(s);
         }
         assertArrayEquals(ordered, result.toArray(new String[0]));
@@ -976,55 +982,52 @@ public class TestNodeValue
         assertArrayEquals(ordered, result.toArray(new String[0]));
     }
 
-    // TODO testSameValueDecimal tests
-    // TODO sameValueAs mixed tests
-
     @Test
     public void testSameValue1() {
         NodeValue nv1 = NodeValue.makeInteger(5);
         NodeValue nv2 = NodeValue.makeInteger(7);
-        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameAs(nv1, nv2));
-        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameAs(nv1, nv2));
+        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameValueAs(nv1, nv2));
+        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameValueAs(nv1, nv2));
 
         NodeValue nv3 = NodeValue.makeInteger(5);
-        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameAs(nv1, nv3));
-        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameAs(nv1, nv3));
+        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameValueAs(nv1, nv3));
+        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameValueAs(nv1, nv3));
     }
 
     @Test
     public void testSameValue2() {
         NodeValue nv1 = NodeValue.makeInteger(5);
         NodeValue nv2 = NodeValue.makeNodeInteger(7);
-        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameAs(nv1, nv2));
-        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameAs(nv1, nv2));
+        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameValueAs(nv1, nv2));
+        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameValueAs(nv1, nv2));
 
         NodeValue nv3 = NodeValue.makeNodeInteger(5);
-        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameAs(nv1, nv3));
-        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameAs(nv1, nv3));
+        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameValueAs(nv1, nv3));
+        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameValueAs(nv1, nv3));
     }
 
     @Test
     public void testSameValue3() {
         NodeValue nv1 = NodeValue.makeDecimal("1.5");
         NodeValue nv2 = NodeValue.makeDecimal("1.6");
-        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameAs(nv1, nv2));
-        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameAs(nv1, nv2));
+        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameValueAs(nv1, nv2));
+        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameValueAs(nv1, nv2));
 
         NodeValue nv3 = NodeValue.makeDecimal("1.50");
-        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameAs(nv1, nv3));
-        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameAs(nv1, nv3));
+        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameValueAs(nv1, nv3));
+        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameValueAs(nv1, nv3));
     }
 
     @Test
     public void testSameValue4() {
         NodeValue nv1 = NodeValue.makeDecimal("3");
         NodeValue nv2 = NodeValue.makeInteger(4);
-        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameAs(nv1, nv2));
-        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameAs(nv1, nv2));
+        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameValueAs(nv1, nv2));
+        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameValueAs(nv1, nv2));
 
         NodeValue nv3 = NodeValue.makeInteger(3);
-        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameAs(nv1, nv3));
-        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameAs(nv1, nv3));
+        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameValueAs(nv1, nv3));
+        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameValueAs(nv1, nv3));
     }
 
     @Test
@@ -1032,36 +1035,81 @@ public class TestNodeValue
         NodeValue nv1 = NodeValue.makeDecimal("-1.5"); // Must be exact for
                                                        // double and decimal
         NodeValue nv2 = NodeValue.makeDouble(1.5);
-        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameAs(nv1, nv2));
-        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameAs(nv1, nv2));
+        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameValueAs(nv1, nv2));
+        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameValueAs(nv1, nv2));
 
         NodeValue nv3 = NodeValue.makeDouble(-1.5);
-        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameAs(nv1, nv3));
-        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameAs(nv1, nv3));
+        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameValueAs(nv1, nv3));
+        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameValueAs(nv1, nv3));
     }
 
     @Test
     public void testSameValue6() {
         NodeValue nv1 = NodeValue.makeNodeInteger(17);
         NodeValue nv2 = NodeValue.makeDouble(34);
-        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameAs(nv1, nv2));
-        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameAs(nv1, nv2));
+        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameValueAs(nv1, nv2));
+        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameValueAs(nv1, nv2));
 
         NodeValue nv3 = NodeValue.makeDouble(17);
-        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameAs(nv1, nv3));
-        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameAs(nv1, nv3));
+        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameValueAs(nv1, nv3));
+        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameValueAs(nv1, nv3));
     }
 
     @Test
     public void testSameValue7() {
         NodeValue nv1 = NodeValue.makeBoolean(true);
         NodeValue nv2 = NodeValue.makeString("a");
-        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameAs(nv1, nv2));
-        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameAs(nv1, nv2));
+        assertTrue("Same values (" + nv1 + "," + nv2 + ")", NodeValue.notSameValueAs(nv1, nv2));
+        assertFalse("Same values (" + nv1 + "," + nv2 + ")", NodeValue.sameValueAs(nv1, nv2));
 
         NodeValue nv3 = NodeValue.makeNodeBoolean(true);
-        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameAs(nv1, nv3));
-        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameAs(nv1, nv3));
+        assertTrue("Different values (" + nv1 + "," + nv3 + ")", NodeValue.sameValueAs(nv1, nv3));
+        assertFalse("Different values - notNotSame (" + nv1 + "," + nv3 + ")", NodeValue.notSameValueAs(nv1, nv3));
+    }
+
+    @Test
+    public void testSameValueNaN_double_1() {
+        NodeValue nv1 = NodeValue.makeNode("NaN", XSDDatatype.XSDdouble);
+        NodeValue nv2 = NodeValue.makeNode("NaN", XSDDatatype.XSDdouble);
+        assertEquals(nv1, nv2);
+        assertFalse(NodeValue.sameValueAs(nv1, nv2));
+        assertTrue(NodeValue.notSameValueAs(nv1, nv2));
+    }
+
+    @Test
+    public void testSameValueNaN_float_1() {
+        NodeValue nv1 = NodeValue.makeNode("NaN", XSDDatatype.XSDfloat);
+        NodeValue nv2 = NodeValue.makeNode("NaN", XSDDatatype.XSDfloat);
+        assertEquals(nv1, nv2);
+        assertFalse(NodeValue.sameValueAs(nv1, nv2));
+        assertTrue(NodeValue.notSameValueAs(nv1, nv2));
+        // NaN is weird.
+        assertFalse(NodeValue.sameValueAs(nv1, nv1));
+        assertTrue(NodeValue.notSameValueAs(nv1, nv1));
+    }
+
+    @Test
+    public void testSameValueNaN_double_2() {
+        NodeValue nv1 = NodeValue.makeDouble(Double.NaN);
+        NodeValue nv2 = NodeValue.makeDouble(Double.NaN);
+        assertEquals(nv1, nv2);
+        assertFalse(NodeValue.sameValueAs(nv1, nv2));
+        assertTrue(NodeValue.notSameValueAs(nv1, nv2));
+
+        assertFalse(NodeValue.sameValueAs(nv1, nv1));
+        assertTrue(NodeValue.notSameValueAs(nv1, nv1));
+    }
+
+    @Test
+    public void testSameValueNaN_float_2() {
+        NodeValue nv1 = NodeValue.makeFloat(Float.NaN);
+        NodeValue nv2 = NodeValue.makeFloat(Float.NaN);
+        assertEquals(nv1, nv2);
+        assertFalse(NodeValue.sameValueAs(nv1, nv2));
+        assertTrue(NodeValue.notSameValueAs(nv1, nv2));
+
+        assertFalse(NodeValue.sameValueAs(nv1, nv1));
+        assertTrue(NodeValue.notSameValueAs(nv1, nv1));
     }
 
     @Test
@@ -1070,7 +1118,7 @@ public class TestNodeValue
         NodeValue nv1 = NodeValue.makeNode(n1);
         Node n2 = org.apache.jena.graph.NodeFactory.createLiteral("xyz", "en");
         NodeValue nv2 = NodeValue.makeNode(n2);
-        assertTrue(NodeValue.sameAs(nv1, nv2));
+        assertTrue(NodeValue.sameValueAs(nv1, nv2));
     }
 
     @Test
@@ -1079,7 +1127,7 @@ public class TestNodeValue
         NodeValue nv1 = NodeValue.makeNode(n1);
         Node n2 = org.apache.jena.graph.NodeFactory.createLiteral("xyz", "EN");
         NodeValue nv2 = NodeValue.makeNode(n2);
-        assertTrue(NodeValue.sameAs(nv1, nv2));
+        assertTrue(NodeValue.sameValueAs(nv1, nv2));
         assertFalse(nv1.equals(nv2));
     }
 
@@ -1089,19 +1137,46 @@ public class TestNodeValue
         NodeValue nv1 = NodeValue.makeNode(n1);
         Node n2 = org.apache.jena.graph.NodeFactory.createLiteral("xyz", "en");
         NodeValue nv2 = NodeValue.makeNode(n2);
-        assertFalse(NodeValue.notSameAs(nv1, nv2));
+        assertFalse(NodeValue.notSameValueAs(nv1, nv2));
     }
 
     @Test
     public void testLang4() {
-        Node n1 = org.apache.jena.graph.NodeFactory.createLiteral("xyz", "en");
-        NodeValue nv1 = NodeValue.makeNode(n1);
-        Node n2 = org.apache.jena.graph.NodeFactory.createLiteral("xyz", "EN");
-        NodeValue nv2 = NodeValue.makeNode(n2);
-        assertFalse(NodeValue.notSameAs(nv1, nv2));
+        NodeValue nv1 = parse("'xyz'@en");
+        NodeValue nv2 = parse("'xyz'@EN");
+        assertFalse(NodeValue.notSameValueAs(nv1, nv2));
         assertFalse(nv1.equals(nv2));
     }
 
+    //Compare value first and then language tag
+    @Test
+    public void testLangCompareAlways1() {
+        // @de before @en => "'abc'@en" > "'bcd'@de" => +1
+        NodeValue nv1 = parse("'abc'@en");
+        NodeValue nv2 = parse("'bcd'@de");
+        assertEquals(Expr.CMP_GREATER, NodeCmp.compareRDFTerms(nv1.getNode(), nv2.getNode()));
+        assertEquals(Expr.CMP_GREATER, NodeValue.compareAlways(nv1, nv2));
+    }
+
+    //Language tag comparison ignore case first, then case sensitive
+    @Test
+    public void testLangCompareAlways2() {
+        // @FR before @it. => "'abc'@it" > "'abc'@FR" => +1
+        NodeValue nv1 = parse("'abc'@it");
+        NodeValue nv2 = parse("'abc'@FR");
+        assertEquals(Expr.CMP_GREATER, NodeCmp.compareRDFTerms(nv1.getNode(), nv2.getNode()));
+        assertEquals(Expr.CMP_GREATER, NodeValue.compareAlways(nv1, nv2));
+    }
+
+    public void testLangCompareAlways3() {
+        // @FR after @en. => "'abc'@en" < "'abc'@FR" => -1
+        NodeValue nv1 = parse("'abc'@en");
+        NodeValue nv2 = parse("'abc'@FR");
+        assertEquals(Expr.CMP_LESS, NodeCmp.compareRDFTerms(nv1.getNode(), nv2.getNode()));
+        assertEquals(Expr.CMP_LESS, NodeValue.compareAlways(nv1, nv2));
+    }
+
+
     @Test
     public void testEquals1() {
         NodeValue nv1 = NodeValue.makeInteger(1);
@@ -1174,12 +1249,13 @@ public class TestNodeValue
 
     @Test
     public void testTripleTerms3() {
+        // Jena 4.6.0 :: 'abc' < before 123
         Node n1 = SSE.parseNode("<<:s :p 123>>");
         Node n2 = SSE.parseNode("<<:s :p 'abc'>>");
         NodeValue nv1 = NodeValue.makeNode(n1);
         NodeValue nv2 = NodeValue.makeNode(n2);
         int x = NodeValue.compareAlways(nv1, nv2);
-        assertEquals(Expr.CMP_LESS, x);
+        assertEquals(Expr.CMP_GREATER, x);
     }
 
 }
