@@ -23,12 +23,13 @@
 
 package org.apache.jena.rdfxml.xmlinput.impl;
 
-import java.net.MalformedURLException ;
 import java.util.HashMap ;
 import java.util.Map ;
 
-import org.apache.jena.iri.IRI ;
-import org.apache.jena.iri.IRIFactory ;
+import org.apache.jena.irix.IRIException;
+import org.apache.jena.irix.IRIProvider;
+import org.apache.jena.irix.IRIx;
+import org.apache.jena.irix.SystemIRIx;
 import org.apache.jena.rdfxml.xmlinput.* ;
 import org.apache.jena.rdfxml.xmlinput.states.Frame ;
 import org.apache.jena.rdfxml.xmlinput.states.FrameI ;
@@ -41,15 +42,14 @@ import org.xml.sax.SAXParseException ;
 
 /**
  * This class converts SAX events into a stream of encapsulated events suitable
- * for the RDF parser. In effect, this is the RDF lexer. updates by kers to
- * handle exporting namespace prefix maps.
+ * for the RDF parser. In effect, this is the RDF lexer.
  */
 public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
         Names {
 
     boolean encodingProblems = false;
 
-    protected Map<IRI, Map<String,ARPLocation>> idsUsed = new HashMap<>();
+    protected Map<IRIx, Map<String,ARPLocation>> idsUsed = new HashMap<>();
     protected int idsUsedCount = 0;
 
     public XMLHandler() {}
@@ -80,7 +80,17 @@ public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
     @Override
     public void startPrefixMapping(String prefix, String uri)
             throws SAXParseException {
+        try {
         checkNamespaceURI(uri);
+        } catch (IRIException ex) {
+            ARPLocation aLoc;
+            if ( frame instanceof Frame ) {
+                aLoc = new ARPLocation(((Frame)frame).arp.getLocator());
+            } else
+                aLoc = new ARPLocation(null);
+
+            throw new ParseException(EM_ERROR, aLoc, ex.getMessage());
+        }
         handlers.getNamespaceHandler().startPrefixMapping(prefix, uri);
     }
 
@@ -293,50 +303,10 @@ public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
                 return new XMLBaselessContext(this,
                         WARN_RESOLVING_URI_AGAINST_EMPTY_BASE);
             } else {
-//                if (base.toLowerCase().startsWith("file:")
-//                    && base.length()>5
-//                    && base.charAt(5) != '/'
-//                ) {
-//                    System.err.print(base);
-//                    try {
-//                        base = new File(base.substring(5)).toURL().toString();
-//                        if (base.length()<=6
-//                                || base.charAt(6)!= '/')
-//                            base = "file://"+base.substring(5);
-//                    } catch (MalformedURLException e) {
-//                        // ignore, just leave it alone.
-//                    }
-//                    System.err.println(" ==> "+base);
-//
-//                }
                 return new XMLBaselessContext(this,
                         ERR_RESOLVING_AGAINST_RELATIVE_BASE).withBase(this,base);
             }
     }
-    /*
-    private XMLContext initialContextWithBasex(String base)
-            throws SAXParseException {
-        XMLContext rslt = new XMLContext(this, base);
-        RDFURIReference b = rslt.getURI();
-        if (base == null) {
-            warning(null,IGN_NO_BASE_URI_SPECIFIED,
-                    "Base URI not specified for input file; local URI references will be in error.");
-
-        } else if (base.equals("")) {
-            warning(null,IGN_NO_BASE_URI_SPECIFIED,
-                    "Base URI specified as \"\"; local URI references will not be resolved.");
-
-        } else {
-            checkBadURI(null,b);
-            // Warnings on bad base.
-
-            // if (b.isVeryBad()||b.isRelative()) {
-            // return
-        }
-
-        return rslt;
-    }
-    */
 
     private ARPOptions options = ARPOptions.createNewOptions() ;
     private ARPHandlers handlers = ARPHandlers.createNewHandlers() ;
@@ -364,7 +334,6 @@ public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
         handlers.setExtendedHandler(newHh.getExtendedHandler());
         handlers.setNamespaceHandler(newHh.getNamespaceHandler());
         handlers.setStatementHandler(newHh.getStatementHandler());
-
     }
 
     private Map<String, Object> nodeIdUserData;
@@ -385,9 +354,7 @@ public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
     }
 
     /**
-     * This method must be always be called after parsing, e.g. in a finally
-     * block.
-     *
+     * This method must be always be called after parsing, e.g. in a finally block.
      */
     void afterParse() {
         while (frame != null) {
@@ -413,31 +380,26 @@ public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
         return new ARPLocation(locator);
     }
 
-    private IRIFactory factory = null ;
-
-    IRIFactory iriFactory() {
-        if (factory == null) {
-            factory = options.getIRIFactory() ;
-            if ( factory == null )
-                factory = ARPOptions.getIRIFactoryGlobal() ;
+    private IRIProvider provider = null ;
+    IRIProvider iriProvider() {
+        if (provider == null) {
+            provider = options.getIRIProvider() ;
+            if ( provider == null )
+                provider = SystemIRIx.getProvider();
         }
-        return factory;
+        return provider;
     }
 
     private void checkNamespaceURI(String uri) throws SAXParseException {
         ((Frame) frame).checkEncoding(null,uri);
         if (uri.length() != 0)
              {
-                IRI u = iriFactory().create(uri);
-//                if (u.isVeryBad()) {
-//                    warning(null,
-//                            WARN_BAD_NAMESPACE_URI,
-//                            "The namespace URI: <"
-//                                    + uri
-//                                    + "> is not well formed.");
-//                    return;
-//
-//                }
+                IRIx u = iriProvider().create(uri);
+                try {
+                    u = IRIx.create(uri);
+                } catch (IRIException ex) {
+                    u = IRIx.createAny(uri);
+                }
                 if (!u.isAbsolute()) {
                     warning(null,
                             WARN_RELATIVE_NAMESPACE_URI_DEPRECATED,
@@ -445,21 +407,6 @@ public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
                                     + uri
                                     + "> is relative. Such use has been deprecated by the W3C, and may result in RDF interoperability failures. Use an absolute namespace URI.");
                 }
-                try {
-                    if (!u.toASCIIString().equals(u.toString()))
-                        warning(null,
-                                WARN_BAD_NAMESPACE_URI,
-                                "Non-ascii characters in a namespace URI may not be completely portable: <"
-                                        + u.toString()
-                                        + ">. Resulting RDF URI references are legal.");
-                } catch (MalformedURLException e) {
-                    warning(null,
-                            WARN_BAD_NAMESPACE_URI,
-                            "Bad namespace URI: <"
-                                    + u.toString()
-                                    + ">. " + e.getMessage());
-              }
-
                 if (uri.startsWith(rdfns) && !uri.equals(rdfns))
                     warning(null,WARN_BAD_RDF_NAMESPACE_URI, "Namespace URI ref <"
                             + uri + "> may not be used in RDF/XML.");
@@ -472,11 +419,10 @@ public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
     public boolean allowRelativeURIs() {
         return allowRelativeReferences;
     }
-    private IRI sameDocRef;
-    public IRI sameDocRef() {
-        if (sameDocRef==null){
-            sameDocRef = iriFactory().create("");
-        }
+    private IRIx sameDocRef;
+    public IRIx sameDocRef() {
+        if (sameDocRef==null)
+            sameDocRef = iriProvider().create("");
         return sameDocRef;
     }
 
@@ -516,6 +462,7 @@ public class XMLHandler extends LexicalHandlerImpl implements ARPErrorNumbers,
     };
 }
 
+// Some contributed code in this file are:
 /*
  *  (c) Copyright 2003, Plugged In Software
  *
