@@ -19,14 +19,14 @@
 package org.apache.jena.dboe.trans;
 
 import org.apache.jena.dboe.trans.bplustree.TS_TxnBPTree;
-import org.apache.jena.dboe.trans.data.TS_TransData;
+import org.apache.jena.dboe.trans.data.TS_TransactionalData;
 import org.apache.jena.dboe.trans.recovery.TestRecovery;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
 @RunWith(Suite.class)
 @Suite.SuiteClasses( {
-    TS_TransData.class
+    TS_TransactionalData.class
     , TS_TxnBPTree.class
     , TestRecovery.class
 })
