@@ -23,6 +23,7 @@ import static arq.cmdline.ModAssembler.assemblerDescDecl;
 import java.net.BindException;
 import java.nio.file.Files;
 import java.nio.file.Path;
+import java.util.ArrayList;
 import java.util.List;
 
 import arq.cmdline.CmdARQ;
@@ -32,14 +33,18 @@ import org.apache.jena.atlas.lib.FileOps;
 import org.apache.jena.atlas.logging.FmtLog;
 import org.apache.jena.atlas.web.AuthScheme;
 import org.apache.jena.cmd.ArgDecl;
+import org.apache.jena.cmd.ArgModuleGeneral;
 import org.apache.jena.cmd.CmdException;
 import org.apache.jena.cmd.TerminationException;
 import org.apache.jena.fuseki.Fuseki;
 import org.apache.jena.fuseki.FusekiException;
+import org.apache.jena.fuseki.main.FusekiMainInfo;
 import org.apache.jena.fuseki.main.FusekiServer;
+import org.apache.jena.fuseki.main.sys.FusekiModules;
+import org.apache.jena.fuseki.main.sys.FusekiAutoModules;
 import org.apache.jena.fuseki.server.DataAccessPoint;
 import org.apache.jena.fuseki.server.DataAccessPointRegistry;
-import org.apache.jena.fuseki.server.FusekiInfo;
+import org.apache.jena.fuseki.server.FusekiCoreInfo;
 import org.apache.jena.fuseki.servlets.SPARQL_QueryGeneral;
 import org.apache.jena.fuseki.validation.DataValidator;
 import org.apache.jena.fuseki.validation.IRIValidator;
@@ -87,6 +92,7 @@ public class FusekiMain extends CmdARQ {
     private static ArgDecl  argGZip         = new ArgDecl(ArgDecl.HasValue, "gzip");
     private static ArgDecl  argBase         = new ArgDecl(ArgDecl.HasValue, "base", "files");
 
+    // This is now a no-op - CORS is included unless "--no-cors" is used.
     private static ArgDecl  argCORS         = new ArgDecl(ArgDecl.NoValue,  "withCORS", "cors", "CORS");
     private static ArgDecl  argNoCORS       = new ArgDecl(ArgDecl.NoValue,  "noCORS", "no-cors");
     private static ArgDecl  argWithPing     = new ArgDecl(ArgDecl.NoValue,  "withPing", "ping");
@@ -94,6 +100,9 @@ public class FusekiMain extends CmdARQ {
     private static ArgDecl  argWithMetrics  = new ArgDecl(ArgDecl.NoValue,  "withMetrics", "metrics");
     private static ArgDecl  argWithCompact  = new ArgDecl(ArgDecl.NoValue,  "withCompact", "compact");
 
+    // Default is "true" and use modules found by the ServiceLoader.
+    private static ArgDecl  argEnableModules  = new ArgDecl(ArgDecl.HasValue,  "modules", "fuseki-modules");
+
     private static ArgDecl  argAuth         = new ArgDecl(ArgDecl.HasValue, "auth");
 
     private static ArgDecl  argHttps        = new ArgDecl(ArgDecl.HasValue, "https");
@@ -107,6 +116,10 @@ public class FusekiMain extends CmdARQ {
     private static ArgDecl  argSparqler     = new ArgDecl(ArgDecl.HasValue, "sparqler");
 
     private static ArgDecl  argValidators   = new ArgDecl(ArgDecl.NoValue,  "validators");
+
+    private static List<ArgModuleGeneral> additionalArgs = new ArrayList<>();
+    public static void addArgModule(ArgModuleGeneral argModule) { additionalArgs.add(argModule); }
+
     // private static ModLocation modLocation = new ModLocation();
     private static ModDatasetAssembler modDataset      = new ModDatasetAssembler();
 
@@ -114,18 +127,42 @@ public class FusekiMain extends CmdARQ {
     // Default
     private boolean useTDB2 = true;
 
+    // -- Programmatic ways to create a server
+
     /** Build, but do not start, a server based on command line syntax. */
-    public static FusekiServer build(String... argv) {
-        FusekiMain inner = new FusekiMain(argv);
-        inner.process();
-        return inner.buildServer();
+    public static FusekiServer build(String... args) {
+        FusekiServer.Builder builder = builder(args);
+        return builder.build();
     }
 
+    /**
+     * Create a {@link org.apache.jena.fuseki.main.FusekiServer.Builder} which has
+     * been setup according to the command line arguments.
+     * The builder can be further modified.
+     */
+    public static FusekiServer.Builder builder(String... args) {
+        // Parses command line, sets arguments.
+        FusekiMain inner = new FusekiMain(args);
+        // Process command line args according to the argument specified.
+        inner.process();
+        // Apply command line/serverConfig to a builder.
+        FusekiServer.Builder builder = inner.builder();
+        applyServerArgs(builder, inner.serverConfig);
+        return builder;
+    }
+
+    /**
+     * Create a server and run, within the same JVM.
+     * This is the command line entry point.
+     */
+
     static void run(String... argv) {
         JenaSystem.init();
         new FusekiMain(argv).mainRun();
     }
 
+    // --
+
     protected FusekiMain(String... argv) {
         super(argv);
 
@@ -134,22 +171,27 @@ public class FusekiMain extends CmdARQ {
             TransactionManager.QueueBatchSize = TransactionManager.QueueBatchSize / 2;
 
         getUsage().startCategory("Fuseki Main");
+
+        additionalArgs.forEach(aMod->super.addModule(aMod));
+
         // Control the order!
         add(argMem, "--mem",
             "Create an in-memory, non-persistent dataset for the server");
         add(argFile, "--file=FILE",
             "Create an in-memory, non-persistent dataset for the server, initialised with the contents of the file");
         add(argTDB2mode, "--tdb2",
-            "Use TDB2 for command line persistent datasets (dfault is TDB1)");
+            "Use TDB2 for command line persistent datasets");
+        add(argTDB1mode, "--tdb1",
+                "Use TDB1 for command line persistent datasets (default is TDB2)");
         add(argTDB, "--loc=DIR",
             "Use an existing TDB database (or create if does not exist)");
         add(argMemTDB, "--memTDB",
             "Create an in-memory, non-persistent dataset using TDB (testing only)");
 //            add(argEmpty, "--empty",
-//                "Run with no datasets and services (validators only)");
-        add(argRDFS, "--rdfs=",
+//                "Run with no datasets and services");
+        add(argRDFS, "--rdfs=FILE",
             "Apply RDFS on top of the dataset");
-        add(argConfig, "--config=",
+        add(argConfig, "--config=FILE",
             "Use a configuration file to determine the services");
         addModule(modDataset);
         add(argEmpty); // Hidden for now.
@@ -172,8 +214,8 @@ public class FusekiMain extends CmdARQ {
         add(argGeneralQuerySvc, "--general=PATH",
             "Add a general SPARQL endpoint (without a dataset) at /PATH");
 
-        add(argAuth, "--auth=[basic|Digest]",
-            "Run the server using basic or digest authentication (dft: digest).");
+        add(argAuth, "--auth=[basic|digest]",
+            "Run the server using basic or digest authentication");
         add(argHttps, "--https=CONF",
             "https certificate access details. JSON file { \"cert\":FILE , \"passwd\"; SECRET } ");
         add(argHttpsPort, "--httpsPort=NUM",
@@ -193,7 +235,9 @@ public class FusekiMain extends CmdARQ {
         add(argWithMetrics, "--metrics",    "Enable /$/metrics");
         add(argWithCompact, "--compact",    "Enable /$/compact/*");
 
-        super.modVersion.addClass(Fuseki.class);
+        add(argEnableModules, "--modules=true|false", "Enable Fuseki modules");
+
+        super.modVersion.addClass("Fuseki", Fuseki.class);
     }
 
     static String argUsage = "[--config=FILE] [--mem|--desc=AssemblerFile|--file=FILE] [--port PORT] /DatasetPathName";
@@ -446,6 +490,24 @@ public class FusekiMain extends CmdARQ {
             serverConfig.jettyConfigFile = jettyConfigFile;
         }
 
+        boolean withModules = hasValueOfTrue(argEnableModules);;
+        if ( withModules ) {
+            // Use the discovered ones.
+            FusekiAutoModules.enable(true);
+            // Allows for external setting of serverConfig.fusekiModules
+            if ( serverConfig.fusekiModules == null ) {
+                FusekiAutoModules.setup();
+                serverConfig.fusekiModules = FusekiAutoModules.load();
+            }
+        } else {
+            // Disabled module discovery.
+            FusekiAutoModules.enable(false);
+            // Allows for external setting of serverConfig.fusekiModules
+            if ( serverConfig.fusekiModules == null ) {
+                serverConfig.fusekiModules = FusekiModules.empty();
+            }
+        }
+
         // 2020-10: Ignore argCORS - CORS is now on by default in Fuseki Main cmd
         serverConfig.withCORS = ! contains(argNoCORS);
         serverConfig.withPing = contains(argWithPing);
@@ -469,8 +531,10 @@ public class FusekiMain extends CmdARQ {
     @Override
     protected void exec() {
         try {
-            FusekiServer server = buildServer(serverConfig);
-            info(server);
+            Logger log = Fuseki.serverLog;
+            FusekiMainInfo.logServerCode(log);
+            FusekiServer server = makeServer(serverConfig);
+            infoCmd(server, log);
             try {
                 server.start();
             } catch (FusekiException ex) {
@@ -497,21 +561,31 @@ public class FusekiMain extends CmdARQ {
         }
     }
 
-    private FusekiServer buildServer() {
-        return buildServer(serverConfig);
-    }
-
-    // ServerConfig -> Setup the builder.
-    private FusekiServer buildServer(ServerConfig serverConfig) {
+    /**
+     * Take a {@link ServerConfig} and make a {@Link FusekiServer}.
+     * The server has not been started.
+     */
+    private FusekiServer makeServer(ServerConfig serverConfig) {
         FusekiServer.Builder builder = builder();
-        return buildServer(builder, serverConfig);
+        applyServerArgs(builder, serverConfig);
+        return builder.build();
     }
 
     protected FusekiServer.Builder builder() {
         return FusekiServer.create();
     }
 
+    /**
+     * Process {@link ServerConfig} and build a server.
+     * The server has not been started.
+     */
     private static FusekiServer buildServer(FusekiServer.Builder builder, ServerConfig serverConfig) {
+        applyServerArgs(builder, serverConfig);
+        return builder.build();
+    }
+
+    /** Apply {@link ServerConfig} to a {@link FusekiServer.Builder}. */
+    private static void applyServerArgs(FusekiServer.Builder builder, ServerConfig serverConfig) {
         if ( serverConfig.jettyConfigFile != null )
             builder.jettyServerConfig(serverConfig.jettyConfigFile);
         builder.port(serverConfig.port);
@@ -539,6 +613,9 @@ public class FusekiMain extends CmdARQ {
                 builder.add(serverConfig.datasetPath, serverConfig.dsg, serverConfig.allowUpdate);
         }
 
+        if ( serverConfig.fusekiModules != null )
+            builder.fusekiModules(serverConfig.fusekiModules);
+
         if ( serverConfig.contentDirectory != null )
             builder.staticFileBase(serverConfig.contentDirectory);
 
@@ -568,19 +645,13 @@ public class FusekiMain extends CmdARQ {
 
         if ( serverConfig.withCompact )
             builder.enableCompact(true);
-
-        return builder.build();
     }
 
-    private void info(FusekiServer server) {
+    /** Information from the command line setup */
+    private void infoCmd(FusekiServer server, Logger log) {
         if ( super.isQuiet() )
             return;
 
-        Logger log = Fuseki.serverLog;
-
-        FusekiInfo.server(log);
-
-        DataAccessPointRegistry dapRegistry = DataAccessPointRegistry.get(server.getServletContext());
         if ( serverConfig.empty ) {
             FmtLog.info(log, "No SPARQL datasets services");
         } else {
@@ -588,6 +659,7 @@ public class FusekiMain extends CmdARQ {
                 log.error("No dataset path nor server configuration file");
         }
 
+        DataAccessPointRegistry dapRegistry = DataAccessPointRegistry.get(server.getServletContext());
         if ( serverConfig.datasetPath != null ) {
             if ( dapRegistry.size() != 1 )
                 log.error("Expected only one dataset in the DataAccessPointRegistry");
@@ -601,8 +673,8 @@ public class FusekiMain extends CmdARQ {
         boolean verbose = serverConfig.verboseLogging;
 
         if ( ! super.isQuiet() )
-            FusekiInfo.logServerSetup(log, verbose, dapRegistry,
-                                      datasetPath, datasetDescription, serverConfigFile, staticFiles);
+            FusekiCoreInfo.logServerCmdSetup(log, verbose, dapRegistry,
+                                             datasetPath, datasetDescription, serverConfigFile, staticFiles);
     }
 
     @Override
