@@ -18,8 +18,6 @@
     'cypress'
   ],
   env: {
-    mocha: true,
-    'cypress/globals': true
   },
   rules: {
     strict: 'off'
