@@ -28,7 +28,10 @@ import org.junit.runners.Suite;
     , TestHttpRDF.class
     , TestAsyncHttpRDF.class
     , TestAuthRemote.class
+    , TestAuthBasicRemote.class
     , TestAuthDigestRemote.class
+    , TestAuthBearerRemote.class
+    , TestAuthBearerServer.class
 })
 
 public class TS_JenaHttp { }
