@@ -18,12 +18,12 @@
 package org.apache.jena.permissions.contract.model;
 
 import org.apache.jena.rdf.model.test.TestLiterals;
-import org.apache.jena.rdf.model.test.TestPackage;
+import org.apache.jena.rdf.model.test.TestPackage_model;
 
 public class SecTestLiterals extends TestLiterals {
 
     public SecTestLiterals() {
-        super(new TestPackage.PlainModelFactory(), "SecTestLiterals");
+        super(new TestPackage_model.PlainModelFactory(), "SecTestLiterals");
     }
 
 }
